@@ -272,16 +272,16 @@ print_statistics(const config_t* config, const times_t* times, stats_t* stats)
 
     printf("Statistics:\n\n");
 
-    printf("  %s sent:         %" PRIu64 "u\n",
+    printf("  %s sent:         %" PRIu64 "\n",
         units, stats->num_sent);
-    printf("  %s completed:    %" PRIu64 "u (%.2lf%%)\n",
+    printf("  %s completed:    %" PRIu64 " (%.2lf%%)\n",
         units, stats->num_completed,
         SAFE_DIV(100.0 * stats->num_completed, stats->num_sent));
-    printf("  %s lost:         %" PRIu64 "u (%.2lf%%)\n",
+    printf("  %s lost:         %" PRIu64 " (%.2lf%%)\n",
         units, stats->num_timedout,
         SAFE_DIV(100.0 * stats->num_timedout, stats->num_sent));
     if (stats->num_interrupted > 0)
-        printf("  %s interrupted:  %" PRIu64 "u (%.2lf%%)\n",
+        printf("  %s interrupted:  %" PRIu64 " (%.2lf%%)\n",
             units, stats->num_interrupted,
             SAFE_DIV(100.0 * stats->num_interrupted, stats->num_sent));
     printf("\n");
@@ -295,7 +295,7 @@ print_statistics(const config_t* config, const times_t* times, stats_t* stats)
             first_rcode = false;
         else
             printf(", ");
-        printf("%s %" PRIu64 "u (%.2lf%%)",
+        printf("%s %" PRIu64 " (%.2lf%%)",
             perf_dns_rcode_strings[i], stats->rcodecounts[i],
             (stats->rcodecounts[i] * 100.0) / stats->num_completed);
     }
